**``cone.app`` - Build Web Applications on top of the pyramid framework.**

.. image:: https://img.shields.io/pypi/v/cone.app.svg
    :target: https://pypi.python.org/pypi/cone.app
    :alt: Latest PyPI version

.. image:: https://img.shields.io/pypi/dm/cone.app.svg
    :target: https://pypi.python.org/pypi/cone.app
    :alt: Number of PyPI downloads

.. image:: https://travis-ci.org/bluedynamics/cone.app.svg?branch=master
    :target: https://travis-ci.org/bluedynamics/cone.app

.. image:: https://coveralls.io/repos/github/bluedynamics/cone.app/badge.svg?branch=master
    :target: https://coveralls.io/github/bluedynamics/cone.app?branch=master


Detailed Documentation
======================

The detailed ``cone.app`` documentation is available 
`here <https://coneapp.readthedocs.io>`_.


Source Code
===========

The sources are in a GIT DVCS with its main branches at 
`github <http://github.com/conestack/cone.app>`_.


Copyright
=========

- Copyright (c) 2009-2021 Cone Contributors


Contributors
============

- Robert Niederreiter (Author)
- Jens Klein
- Georg Gogo. BERNHARD
- Phil Auersperg
- Florian Friesdorf
- Attila Olah
- Peter Holzer
- Johannes Raggam
